==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServicePlanFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServicePlanFluentImpl<A extends ClusterServicePlanFluent<A>> extends BaseFluent<A> implements ClusterServicePlanFluent<A>{
  public ClusterServicePlanFluentImpl() {
  }
  public ClusterServicePlanFluentImpl(ClusterServicePlan instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterServicePlanSpecBuilder spec;
  private ClusterServicePlanStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterServicePlanFluent.MetadataNested<A> withNewMetadata() {
    return new ClusterServicePlanFluentImpl.MetadataNestedImpl();
  }
  public ClusterServicePlanFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterServicePlanFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterServicePlanFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterServicePlanFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterServicePlanFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServicePlanSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterServicePlanSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterServicePlanSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterServicePlanSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterServicePlanFluent.SpecNested<A> withNewSpec() {
    return new ClusterServicePlanFluentImpl.SpecNestedImpl();
  }
  public ClusterServicePlanFluent.SpecNested<A> withNewSpecLike(ClusterServicePlanSpec item) {
    return new ClusterServicePlanFluentImpl.SpecNestedImpl(item);
  }
  public ClusterServicePlanFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterServicePlanFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServicePlanSpecBuilder().build());
  }
  public ClusterServicePlanFluent.SpecNested<A> editOrNewSpecLike(ClusterServicePlanSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServicePlanStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterServicePlanStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterServicePlanStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterServicePlanStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean removedFromBrokerCatalog) {
    return (A)withStatus(new ClusterServicePlanStatus(removedFromBrokerCatalog));
  }
  public ClusterServicePlanFluent.StatusNested<A> withNewStatus() {
    return new ClusterServicePlanFluentImpl.StatusNestedImpl();
  }
  public ClusterServicePlanFluent.StatusNested<A> withNewStatusLike(ClusterServicePlanStatus item) {
    return new ClusterServicePlanFluentImpl.StatusNestedImpl(item);
  }
  public ClusterServicePlanFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterServicePlanFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServicePlanStatusBuilder().build());
  }
  public ClusterServicePlanFluent.StatusNested<A> editOrNewStatusLike(ClusterServicePlanStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterServicePlanFluentImpl that = (ClusterServicePlanFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterServicePlanFluent.MetadataNested<N>> implements ClusterServicePlanFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterServicePlanSpecFluentImpl<ClusterServicePlanFluent.SpecNested<N>> implements ClusterServicePlanFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterServicePlanSpec item) {
      this.builder = new ClusterServicePlanSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterServicePlanSpecBuilder(this);
    }
    ClusterServicePlanSpecBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterServicePlanStatusFluentImpl<ClusterServicePlanFluent.StatusNested<N>> implements ClusterServicePlanFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterServicePlanStatus item) {
      this.builder = new ClusterServicePlanStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterServicePlanStatusBuilder(this);
    }
    ClusterServicePlanStatusBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServicePlanFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServicePlanFluentImpl<A extends ClusterServicePlanFluent<A>> extends BaseFluent<A> implements ClusterServicePlanFluent<A>{
  public ClusterServicePlanFluentImpl() {
  }
  public ClusterServicePlanFluentImpl(ClusterServicePlan instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterServicePlanSpecBuilder spec;
  private ClusterServicePlanStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterServicePlanFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ClusterServicePlanFluentImpl.MetadataNestedImpl();
  }
  public ClusterServicePlanFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterServicePlanFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterServicePlanFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterServicePlanFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterServicePlanFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServicePlanSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterServicePlanSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterServicePlanSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterServicePlanSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterServicePlanFluentImpl.SpecNested<A> withNewSpec() {
    return new ClusterServicePlanFluentImpl.SpecNestedImpl();
  }
  public ClusterServicePlanFluentImpl.SpecNested<A> withNewSpecLike(ClusterServicePlanSpec item) {
    return new ClusterServicePlanFluentImpl.SpecNestedImpl(item);
  }
  public ClusterServicePlanFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterServicePlanFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServicePlanSpecBuilder().build());
  }
  public ClusterServicePlanFluentImpl.SpecNested<A> editOrNewSpecLike(ClusterServicePlanSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServicePlanStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterServicePlanStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterServicePlanStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterServicePlanStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean removedFromBrokerCatalog) {
    return (A)withStatus(new ClusterServicePlanStatus(removedFromBrokerCatalog));
  }
  public ClusterServicePlanFluentImpl.StatusNested<A> withNewStatus() {
    return new ClusterServicePlanFluentImpl.StatusNestedImpl();
  }
  public ClusterServicePlanFluentImpl.StatusNested<A> withNewStatusLike(ClusterServicePlanStatus item) {
    return new ClusterServicePlanFluentImpl.StatusNestedImpl(item);
  }
  public ClusterServicePlanFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterServicePlanFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServicePlanStatusBuilder().build());
  }
  public ClusterServicePlanFluentImpl.StatusNested<A> editOrNewStatusLike(ClusterServicePlanStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServicePlanFluentImpl that = (ClusterServicePlanFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterServicePlanFluentImpl.MetadataNested<N>> implements ClusterServicePlanFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterServicePlanSpecFluentImpl<ClusterServicePlanFluentImpl.SpecNested<N>> implements ClusterServicePlanFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterServicePlanSpec item) {
      this.builder = new ClusterServicePlanSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterServicePlanSpecBuilder(this);
    }
    ClusterServicePlanSpecBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterServicePlanStatusFluentImpl<ClusterServicePlanFluentImpl.StatusNested<N>> implements ClusterServicePlanFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterServicePlanStatus item) {
      this.builder = new ClusterServicePlanStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterServicePlanStatusBuilder(this);
    }
    ClusterServicePlanStatusBuilder builder;
    public N and() {
      return (N) ClusterServicePlanFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
